==> common-search-1.0-20130926.093238-3-sources.jar: cn/pconline/search/common/web/CommonController.java <==
package cn.pconline.search.common.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;

/**
 * 公用WebController
 * 
 * @author zengjie
 * @since 2013-9-18
 * @see
 */
public class CommonController
{

    /**
     * 是否包含指定敏感词
     * 
     * @param query
     * @param words
     * @return
     */
    public static boolean hasSensitiveWord(String query, String... words)
    {
        if (StringUtils.isBlank(query))
        {
            return false;
        }
        for (String word : words)
        {
            if (query.contains(word))
            {
                return true;
            }
        }
        return false;
    }

    /**
     * 设置HTTP客户端缓存
     * 
     * @param rsp
     * @param timeToExpire
     */
    public static void setHttpCache(HttpServletResponse rsp, long timeToExpire)
    {
        rsp.setDateHeader("Expires", System.currentTimeMillis() + timeToExpire);
    }

    public static String getStringParam(HttpServletRequest req, String key,
            String def)
    {
        String value = req.getParameter(key);
        if (value == null)
        {
            return def;
        }
        return value;
    }

    public static Integer getIntParam(HttpServletRequest req, String key,
            Integer def)
    {
        String value = req.getParameter(key);
        if (value == null)
        {
            return def;
        }
        try
        {
            return Integer.parseInt(value);
        }
        catch (NumberFormatException e)
        {
            return def;
        }
    }
    
}

==> common-search-1.0-20131018.095843-5-sources.jar: cn/pconline/search/common/web/CommonController.java <==
package cn.pconline.search.common.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;

import cn.pconline.search.common.SearchFrame;
import cn.pconline.search.common.tools.sensitive.SensitiveFilter;

/**
 * 公用WebController
 * 
 * @author zengjie
 * @since 2013-9-18
 * @see
 */
public class CommonController
{

    protected static final SearchFrame SEARCH_FRAME = SearchFrame.get();

    /**
     * 是否包含指定敏感词
     * 
     * @param query
     * @param words
     * @return
     * @Deprecated {@link SearchFrame#getSensitiveFilter()}
     */
    @Deprecated
    public static boolean hasSensitiveWord(String query, String... words)
    {
        if (StringUtils.isBlank(query))
        {
            return false;
        }
        for (String word : words)
        {
            if (query.contains(word))
            {
                return true;
            }
        }
        return false;
    }

    /**
     * 设置HTTP客户端缓存
     * 
     * @param rsp
     * @param timeToExpire
     */
    public static void setHttpCache(HttpServletResponse rsp, long timeToExpire)
    {
        rsp.setDateHeader("Expires", System.currentTimeMillis() + timeToExpire);
    }

    public static String getStringParam(HttpServletRequest req, String key,
            String def)
    {
        String value = req.getParameter(key);
        if (value == null)
        {
            return def;
        }
        return value;
    }

    public static Integer getIntParam(HttpServletRequest req, String key,
            Integer def)
    {
        String value = req.getParameter(key);
        if (value == null)
        {
            return def;
        }
        try
        {
            return Integer.parseInt(value);
        }
        catch (NumberFormatException e)
        {
            return def;
        }
    }
    
    protected static boolean isInvalidRequest(String q, boolean internal)
    {
        SensitiveFilter sensitiveFilter = SEARCH_FRAME.getSensitiveFilter();
        if (StringUtils.isBlank(q)
                || (!internal && sensitiveFilter.matchSensitive(q).find()))
        {
            return true;
        }
        return false;
    }

}
